<?php

/**
 * @file
 *   drush integration for jQuery-viewport-checker.
 */

/**
 * Implementation of hook_drush_command().
 *
 * In this hook, you specify which commands your
 * drush module makes available, what it does and
 * description.
 *
 * Notice how this structure closely resembles how
 * you define menu hooks.
 *
 * See `drush topic docs-commands` for a list of recognized keys.
 *
 * @return array
 *   An associative array describing your command(s).
 */
function viewportchecker_drush_command() {
  $items = [];

  // the key in the $items array is the name of the command.
  $items['viewportchecker:library'] = [
    'callback' => 'drush_viewportchecker_download',
    'description' => dt('Download and install the jQuery-viewport-checker library.'),
    'bootstrap' => DRUSH_BOOTSTRAP_DRUSH, // No bootstrap.
    'aliases' => ['vpc-dl'],
  ];

  return $items;
}

/**
 * Command to download the jQuery-viewport-checker library.
 */
function _viewportchecker_download_file($URL, $filename) {
  $curl = curl_init();
  curl_setopt($curl, CURLOPT_URL, $URL);
  curl_setopt($curl, CURLOPT_HEADER, 0);
  curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
  $result = curl_exec($curl);
  if (!$result) {
    return FALSE;
  }
  curl_close($curl);

  $file = fopen($filename, "w+");
  if (!fputs($file, $result)) {
    return FALSE;
  }
  fclose($file);

  return TRUE;
}

/**
 * Command to download the jQuery-viewport-checker library.
 */
function drush_viewportchecker_download() {
  $path = 'sites/all/libraries/jquery.viewportchecker';
  $lib_name_min = 'jquery.viewportchecker.min.js';
  $lib_name = 'jquery.viewportchecker.js';
  $vpc_download_uri_min = 'https://raw.githubusercontent.com/dirkgroenen/jQuery-viewport-checker/master/dist/jquery.viewportchecker.min.js';
  $vpc_download_uri = 'https://raw.githubusercontent.com/dirkgroenen/jQuery-viewport-checker/master/src/jquery.viewportchecker.js';

  // Create the path if it does not exist.
  if (!is_dir($path)) {
    drush_op('mkdir', $path);
    drush_print('Directory sites/all/libraries/jquery.viewportchecker was created');
  }

  // Download jQuery-viewport-checker library only if path is writable.
  if (is_writable($path)) {
    // Set the directory to the download location.
    $olddir = getcwd();
    chdir($path);

    if ($downloadsuccess = _viewportchecker_download_file($vpc_download_uri_min, $lib_name_min)) {
      drush_print('The library ' . $lib_name_min . ' was successfully downloaded!');
    }
    else {
      drush_print('Cant download the library ' . $lib_name_min);
    }

    if ($downloadsuccess = _viewportchecker_download_file($vpc_download_uri, $lib_name)) {
      drush_print('The library ' . $lib_name . ' was successfully downloaded!');
    }
    else {
      drush_print('Cant download the library ' . $lib_name);
    }

    // Set working directory back to the previous working directory.
    chdir($olddir);
  }
  else {
    drush_print(dt('Drush was unable to install the jQuery-viewport-checker library because @path is not writable.', ['@path' => $path]), 'warning');
  }

}
